@@ -24,7 +24,7 @@ class Variable
     @vtype = vtype.downcase
   end
 
-  attr_reader (:name, :attr, :ary, :vtype)
+  attr_reader(:name, :attr, :ary, :vtype)
 end
 
 def pre_filter(decl)
@@ -101,7 +101,8 @@ def new_def( args_org, args_new, del_argname )
       def #{$method_name}( #{args_new.collect{|i| i.name}.join(',')} )
   EOS
   method_def.concat( del_arg_deriv( args_new, del_argname ) )
-  method_def.concat( check_array_size( args_new ) )
+  args_org_names = args_org.collect{|arg| arg.name}
+  method_def.concat( check_array_size( args_new, args_org_names ) )
   method_def.concat( <<-EOS
 
         #< call the original method >
@@ -196,7 +197,7 @@ def inv_arithm(lendef, varname)
     form = "LEN * #{$1}"
   when /^#{varname} *\+ *(\w+)$/
     form = "LEN - #{$1}"
-  when /^(\w+) *\* *#{varname} *\+ *(\w+)$/
+  when /^\(*(\w+) *\* *#{varname} *\+ *(\w+)\)*$/
     form = "( LEN - #{$2} ) / #{$1}"
   else
     raise 'unsuppoerted dimension specification : '+lendef
@@ -215,7 +216,7 @@ def inv_deriv(argname, shape, aryname)
       form.sub!('LEN',"len_#{aryname}_#{idim}")
       if multiD
 	deriv = <<-EOS
-        if ( !(#{aryname}.is_a?(NArray)) || (#{aryname}.rank < #{idim+1}) )
+        if ( not_nary(#{aryname}) || (#{aryname}.rank < #{idim+1}) )
           raise "#{aryname} must be a NArray of rank == #{shape.length}"
         end
         len_#{aryname}_#{idim} = #{aryname}.shape[#{idim}]
@@ -239,12 +240,22 @@ end
 def aster2dimlen_if_possible( varname, dimlen ) 
   if $method_name =~ /(^rvmax|^rvmin)/ && varname == 'rx'
     dimlen.replace('(len=1; ns.each{|i| len*=i}; len)')
+    true
   else
     raise $!
   end
 end
 
-def check_array_size( args_new )
+def consist_of_names?(str, names)
+  ary = str.split(/\W/).uniq     
+  names.each{|str| ary.delete(str)}
+  ary.each do |str| 
+    return false if (/^\d*$/ !~ str)
+  end
+  true
+end
+
+def check_array_size( args_new, args_org_names )
   body = <<-EOS
 
         #< check array size(s) >
@@ -253,11 +264,12 @@ def check_array_size( args_new )
     if ( v.ary )
       shape = v.ary.split(',')
       if ( shape.length == 1 )
+	arylen_replaced = false
 	if ( shape[0] == '*' )
 	  begin
 	    raise "Array #{v.name} is declared using *"
 	  rescue
-	    aster2dimlen_if_possible( v.name, shape[0] ) 
+	    arylen_replaced = aster2dimlen_if_possible( v.name, shape[0] ) 
 	  end
 	end
 	if possibly_rundef?(nil, v.name)
@@ -265,10 +277,12 @@ def check_array_size( args_new )
 	else
 	  ins = ""
 	end
-        body.concat( <<-EOS
+	if arylen_replaced || consist_of_names?(shape[0], args_org_names )
+	body.concat( <<-EOS
         raise "Invalid array length: #{v.name}.length != #{shape[0]}" if #{ins}#{v.name}.length != (#{shape[0]})
 	EOS
 	)
+	end
       else
 	shape.each_index do |i|
  	  if ( shape[i] == '*' )
@@ -286,13 +300,10 @@ def check_array_size( args_new )
 end
 
 def head
-  return <<-EOS
-require "narray"
-require "numru/dcl_raw"
-module NumRu
-    module DCL
-
-  EOS
+  f = File.open('dcl_rb_heading')
+  heading = f .readlines
+  f.close
+  heading
 end
 
 def close
@@ -315,18 +326,42 @@ def post_filter( ndf )
   end
 end
 
+def delete_comment(src) # [ruby-list:32030] [ruby-list:32049]
+  src.gsub(%r@ ([\'\"])(\\.|.)*?\1
+               | (/\*.*?\*/)      
+               | (//)[^\n]*$      
+               @mx) {
+    if $3
+      s = $3.delete("^\n")
+      s = ' ' if s.empty?
+      s
+    elsif $4
+      ''
+    else
+      $&
+    end
+  }
+end
 
 #####################  (main) ###########################
+require "tempfile"
 files = ARGV
 ofilename = "src/lib/dcl.rb"
 ofile = open( ofilename, "w+" )
 ofile.puts( head() )
 for f in files
   print "processing file #{f}\n"
-  proto = open("| cat #{f} | gcc -E -", "r+")
-  proto.close_write
+  #proto = open("| cat #{f} | gcc -E -", "r+")
+  #proto.close_write
+  fl = File.open(f)
+  proto = Tempfile.new('proto', '.')
+  proto.print( delete_comment(fl.read) )
+  proto.sync
+  proto.rewind
+  fl.close
   while ( line = proto.gets )
-    if line =~ /^ *SUBROUTINE *(\w+)|^ *\w+ *FUNCTION *(\w+)/
+    case line
+    when /^ *SUBROUTINE *(\w+)|^ *\w+ *FUNCTION *(\w+)/
       $method_name = ( $1 || $2 ).downcase
       print $method_name+"\n" if $DEBUG
       args_org = extract_args(proto)
@@ -337,8 +372,15 @@ for f in files
 	post_filter( ndf )
 	ofile.puts( ndf )
       end
+    when /^#if *DCLVER *([<=>]+) *(\d\d)/
+      op = $1
+      ver = "'"+$2[0..0]+'.'+$2[1..1]+"'"   # "'5.2'" etc
+      ofile.print("      if DCLVERSION #{op} #{ver}\n")
+    when /^#endif/
+      ofile.print("      end\n\n")
     end
   end
+  proto.close
 end
 
 ofile.puts( close() )
