@@ -3593,6 +3593,130 @@ dcl_sgrqin(obj, cp)
     return in;
 
 }
+
+#if DCLVER >= 53
+
+static VALUE
+dcl_sgpcmd(obj)
+    VALUE obj;
+{
+    sgpcmd_();
+
+    return Qnil;
+
+}
+
+#endif
+
+#if DCLVER >= 53
+
+static VALUE
+dcl_sgscmn(obj, nc)
+    VALUE obj, nc;
+{
+    integer i_nc;
+
+    if ((TYPE(nc) != T_BIGNUM) || (TYPE(nc) != T_FIXNUM)) {
+      nc = rb_funcall(nc, rb_intern("to_i"), 0);
+    }
+
+    i_nc = NUM2INT(nc);
+
+
+    sgscmn_(&i_nc);
+
+    return Qnil;
+
+}
+
+#endif
+
+#if DCLVER >= 53
+
+static VALUE
+dcl_sgqcmn(obj)
+    VALUE obj;
+{
+    integer o_nmax;
+    VALUE nmax;
+
+    sgqcmn_(&o_nmax);
+
+    nmax = INT2NUM(o_nmax);
+
+
+    return nmax;
+
+}
+
+#endif
+
+#if DCLVER >= 53
+
+static VALUE
+dcl_sgscwd(obj, cxmin, cxmax, cymin, cymax)
+    VALUE obj, cxmin, cxmax, cymin, cymax;
+{
+    real i_cxmin;
+    real i_cxmax;
+    real i_cymin;
+    real i_cymax;
+
+    if (TYPE(cxmin) != T_FLOAT) {
+      cxmin = rb_funcall(cxmin, rb_intern("to_f"), 0);
+    }
+    if (TYPE(cxmax) != T_FLOAT) {
+      cxmax = rb_funcall(cxmax, rb_intern("to_f"), 0);
+    }
+    if (TYPE(cymin) != T_FLOAT) {
+      cymin = rb_funcall(cymin, rb_intern("to_f"), 0);
+    }
+    if (TYPE(cymax) != T_FLOAT) {
+      cymax = rb_funcall(cymax, rb_intern("to_f"), 0);
+    }
+
+    i_cxmin = (real)NUM2DBL(cxmin);
+    i_cxmax = (real)NUM2DBL(cxmax);
+    i_cymin = (real)NUM2DBL(cymin);
+    i_cymax = (real)NUM2DBL(cymax);
+
+
+    sgscwd_(&i_cxmin, &i_cxmax, &i_cymin, &i_cymax);
+
+    return Qnil;
+
+}
+
+#endif
+
+#if DCLVER >= 53
+
+static VALUE
+dcl_sgqcwd(obj)
+    VALUE obj;
+{
+    real o_cxmin;
+    real o_cxmax;
+    real o_cymin;
+    real o_cymax;
+    VALUE cxmin;
+    VALUE cxmax;
+    VALUE cymin;
+    VALUE cymax;
+
+    sgqcwd_(&o_cxmin, &o_cxmax, &o_cymin, &o_cymax);
+
+    cxmin = rb_float_new((double)o_cxmin);
+    cxmax = rb_float_new((double)o_cxmax);
+    cymin = rb_float_new((double)o_cymin);
+    cymax = rb_float_new((double)o_cymax);
+
+
+    return rb_ary_new3(4, cxmin, cxmax, cymin, cymax);
+
+}
+
+#endif
 void
 init_grph1_sgpack(mDCL)
 VALUE mDCL;
@@ -3729,4 +3853,19 @@ VALUE mDCL;
     rb_define_module_function(mDCL, "sgrqvl", dcl_sgrqvl, 1);
     rb_define_module_function(mDCL, "sgrsvl", dcl_sgrsvl, 2);
     rb_define_module_function(mDCL, "sgrqin", dcl_sgrqin, 1);
+#if DCLVER >= 53
+    rb_define_module_function(mDCL, "sgpcmd", dcl_sgpcmd, 0);
+#endif
+#if DCLVER >= 53
+    rb_define_module_function(mDCL, "sgscmn", dcl_sgscmn, 1);
+#endif
+#if DCLVER >= 53
+    rb_define_module_function(mDCL, "sgqcmn", dcl_sgqcmn, 0);
+#endif
+#if DCLVER >= 53
+    rb_define_module_function(mDCL, "sgscwd", dcl_sgscwd, 4);
+#endif
+#if DCLVER >= 53
+    rb_define_module_function(mDCL, "sgqcwd", dcl_sgqcwd, 0);
+#endif
 }
