@@ -215,6 +215,67 @@ dcl_stitrn(obj, vx, vy)
 
 }
 
+#if DCLVER >= 53
+
+static VALUE
+dcl_ststri(obj, itr)
+    VALUE obj, itr;
+{
+    integer i_itr;
+
+    if ((TYPE(itr) != T_BIGNUM) || (TYPE(itr) != T_FIXNUM)) {
+      itr = rb_funcall(itr, rb_intern("to_i"), 0);
+    }
+
+    i_itr = NUM2INT(itr);
+
+
+    ststri_(&i_itr);
+
+    return Qnil;
+
+}
+
+#endif
+
+#if DCLVER >= 53
+
+static VALUE
+dcl_ststrp(obj, cxa, cya, vxoff, vyoff)
+    VALUE obj, cxa, cya, vxoff, vyoff;
+{
+    real i_cxa;
+    real i_cya;
+    real i_vxoff;
+    real i_vyoff;
+
+    if (TYPE(cxa) != T_FLOAT) {
+      cxa = rb_funcall(cxa, rb_intern("to_f"), 0);
+    }
+    if (TYPE(cya) != T_FLOAT) {
+      cya = rb_funcall(cya, rb_intern("to_f"), 0);
+    }
+    if (TYPE(vxoff) != T_FLOAT) {
+      vxoff = rb_funcall(vxoff, rb_intern("to_f"), 0);
+    }
+    if (TYPE(vyoff) != T_FLOAT) {
+      vyoff = rb_funcall(vyoff, rb_intern("to_f"), 0);
+    }
+
+    i_cxa = (real)NUM2DBL(cxa);
+    i_cya = (real)NUM2DBL(cya);
+    i_vxoff = (real)NUM2DBL(vxoff);
+    i_vyoff = (real)NUM2DBL(vyoff);
+
+
+    ststrp_(&i_cxa, &i_cya, &i_vxoff, &i_vyoff);
+
+    return Qnil;
+
+}
+
+#endif
+
 static VALUE
 dcl_ststrn(obj, itr, cxa, cya, vxoff, vyoff)
     VALUE obj, itr, cxa, cya, vxoff, vyoff;
@@ -1074,6 +1135,12 @@ VALUE mDCL;
     rb_define_module_function(mDCL, "ststrf", dcl_ststrf, 1);
     rb_define_module_function(mDCL, "stftrn", dcl_stftrn, 2);
     rb_define_module_function(mDCL, "stitrn", dcl_stitrn, 2);
+#if DCLVER >= 53
+    rb_define_module_function(mDCL, "ststri", dcl_ststri, 1);
+#endif
+#if DCLVER >= 53
+    rb_define_module_function(mDCL, "ststrp", dcl_ststrp, 4);
+#endif
     rb_define_module_function(mDCL, "ststrn", dcl_ststrn, 5);
     rb_define_module_function(mDCL, "stfrot", dcl_stfrot, 2);
     rb_define_module_function(mDCL, "stirot", dcl_stirot, 2);
