@@ -1729,6 +1729,100 @@ dcl_swrqin(obj, cp)
     return in;
 
 }
+
+#if DCLVER >= 53
+
+static VALUE
+dcl_swcmll(obj)
+    VALUE obj;
+{
+    swcmll_();
+
+    return Qnil;
+
+}
+
+#endif
+
+#if DCLVER >= 53
+
+static VALUE
+dcl_swqcmn(obj)
+    VALUE obj;
+{
+    integer o_nn;
+    VALUE nn;
+
+    swqcmn_(&o_nn);
+
+    nn = INT2NUM(o_nn);
+
+
+    return nn;
+
+}
+
+#endif
+
+#if DCLVER >= 53
+
+static VALUE
+dcl_swqcmf(obj, ntx)
+    VALUE obj, ntx;
+{
+    integer i_ntx;
+    char *o_ctf;
+    VALUE ctf;
+
+    if ((TYPE(ntx) != T_BIGNUM) || (TYPE(ntx) != T_FIXNUM)) {
+      ntx = rb_funcall(ntx, rb_intern("to_i"), 0);
+    }
+
+    i_ntx = NUM2INT(ntx);
+
+    o_ctf= ALLOCA_N(char, (DFLT_SIZE+1));
+    memset(o_ctf, '\0', DFLT_SIZE+1);
+
+    swqcmf_(&i_ntx, o_ctf, (ftnlen)DFLT_SIZE);
+
+    ctf = rb_str_new2(o_ctf);
+
+
+    return ctf;
+
+}
+
+#endif
+
+#if DCLVER >= 53
+
+static VALUE
+dcl_swqcmd(obj, ntx)
+    VALUE obj, ntx;
+{
+    integer i_ntx;
+    char *o_ctd;
+    VALUE ctd;
+
+    if ((TYPE(ntx) != T_BIGNUM) || (TYPE(ntx) != T_FIXNUM)) {
+      ntx = rb_funcall(ntx, rb_intern("to_i"), 0);
+    }
+
+    i_ntx = NUM2INT(ntx);
+
+    o_ctd= ALLOCA_N(char, (DFLT_SIZE+1));
+    memset(o_ctd, '\0', DFLT_SIZE+1);
+
+    swqcmd_(&i_ntx, o_ctd, (ftnlen)DFLT_SIZE);
+
+    ctd = rb_str_new2(o_ctd);
+
+
+    return ctd;
+
+}
+
+#endif
 void
 init_grph1_swpack(mDCL)
 VALUE mDCL;
@@ -1808,4 +1902,16 @@ VALUE mDCL;
     rb_define_module_function(mDCL, "swrqvl", dcl_swrqvl, 1);
     rb_define_module_function(mDCL, "swrsvl", dcl_swrsvl, 2);
     rb_define_module_function(mDCL, "swrqin", dcl_swrqin, 1);
+#if DCLVER >= 53
+    rb_define_module_function(mDCL, "swcmll", dcl_swcmll, 0);
+#endif
+#if DCLVER >= 53
+    rb_define_module_function(mDCL, "swqcmn", dcl_swqcmn, 0);
+#endif
+#if DCLVER >= 53
+    rb_define_module_function(mDCL, "swqcmf", dcl_swqcmf, 1);
+#endif
+#if DCLVER >= 53
+    rb_define_module_function(mDCL, "swqcmd", dcl_swqcmd, 1);
+#endif
 }
