@@ -1437,6 +1437,29 @@ dcl_umrqin(obj, cp)
     return in;
 
 }
+
+#if DCLVER >= 53
+
+static VALUE
+dcl_umfmap(obj, cdsn)
+    VALUE obj, cdsn;
+{
+    char *i_cdsn;
+
+    if (TYPE(cdsn) != T_STRING) {
+      cdsn = rb_funcall(cdsn, rb_intern("to_str"), 0);
+    }
+
+    i_cdsn = STR2CSTR(cdsn);
+
+
+    umfmap_(i_cdsn, (ftnlen)strlen(i_cdsn));
+
+    return Qnil;
+
+}
+
+#endif
 void
 init_grph2_umpack(mDCL)
 VALUE mDCL;
@@ -1506,4 +1529,7 @@ VALUE mDCL;
     rb_define_module_function(mDCL, "umrqvl", dcl_umrqvl, 1);
     rb_define_module_function(mDCL, "umrsvl", dcl_umrsvl, 2);
     rb_define_module_function(mDCL, "umrqin", dcl_umrqin, 1);
+#if DCLVER >= 53
+    rb_define_module_function(mDCL, "umfmap", dcl_umfmap, 1);
+#endif
 }
