@@ -215,12 +215,12 @@ dcl_shtfun(obj, mm, jm, m, work)
     i_m = NUM2INT(m);
     i_work = dcl_obj2crealary(work);
 
-    o_fun= ALLOCA_N(real, (2*i_jm+1)*(i_mm-i_m+1));
+    o_fun= ALLOCA_N(real, ((2*i_jm+1)*(i_mm-i_m+1)));
 
     shtfun_(&i_mm, &i_jm, &i_m, o_fun, i_work);
 
-    {int array_shape[1] = {(2*i_jm+1)*(i_mm-i_m+1)};
-     fun = dcl_crealary2obj(o_fun, (2*i_jm+1)*(i_mm-i_m+1), 1, array_shape);
+    {int array_shape[2] = {(2*i_jm+1), (i_mm-i_m+1)};
+     fun = dcl_crealary2obj(o_fun, ((2*i_jm+1)*(i_mm-i_m+1)), 2, array_shape);
     }
 
     dcl_freecrealary(i_work);
@@ -395,12 +395,12 @@ dcl_shts2w(obj, mm, jm, isw, s, work)
     i_s = dcl_obj2crealary(s);
     i_work = dcl_obj2crealary(work);
 
-    o_w= ALLOCA_N(real, (2*i_jm+1)*(2*i_mm+1));
+    o_w= ALLOCA_N(real, ((2*i_jm+1)*(2*i_mm+1)));
 
     shts2w_(&i_mm, &i_jm, &i_isw, i_s, o_w, i_work);
 
-    {int array_shape[1] = {(2*i_jm+1)*(2*i_mm+1)};
-     w = dcl_crealary2obj(o_w, (2*i_jm+1)*(2*i_mm+1), 1, array_shape);
+    {int array_shape[2] = {(2*i_jm+1), (2*i_mm+1)};
+     w = dcl_crealary2obj(o_w, ((2*i_jm+1)*(2*i_mm+1)), 2, array_shape);
     }
 
     dcl_freecrealary(i_s);
@@ -462,12 +462,12 @@ dcl_shtswa(obj, mm, jm, isw, m1, m2, s, work)
     i_s = dcl_obj2crealary(s);
     i_work = dcl_obj2crealary(work);
 
-    o_w= ALLOCA_N(real, (2*i_jm+1)*(2*i_mm+1));
+    o_w= ALLOCA_N(real, ((2*i_jm+1)*(2*i_mm+1)));
 
     shtswa_(&i_mm, &i_jm, &i_isw, &i_m1, &i_m2, i_s, o_w, i_work);
 
-    {int array_shape[1] = {(2*i_jm+1)*(2*i_mm+1)};
-     w = dcl_crealary2obj(o_w, (2*i_jm+1)*(2*i_mm+1), 1, array_shape);
+    {int array_shape[2] = {(2*i_jm+1), (2*i_mm+1)};
+     w = dcl_crealary2obj(o_w, ((2*i_jm+1)*(2*i_mm+1)), 2, array_shape);
     }
 
     dcl_freecrealary(i_s);
@@ -716,12 +716,12 @@ dcl_shtw2s(obj, mm, jm, isw, s, work)
     i_s = dcl_obj2crealary(s);
     i_work = dcl_obj2crealary(work);
 
-    o_w= ALLOCA_N(real, (i_mm+1)*(i_mm+1));
+    o_w= ALLOCA_N(real, ((i_mm+1)*(i_mm+1)));
 
     shtw2s_(&i_mm, &i_jm, &i_isw, i_s, o_w, i_work);
 
-    {int array_shape[1] = {(i_mm+1)*(i_mm+1)};
-     w = dcl_crealary2obj(o_w, (i_mm+1)*(i_mm+1), 1, array_shape);
+    {int array_shape[2] = {(i_mm+1), (i_mm+1)};
+     w = dcl_crealary2obj(o_w, ((i_mm+1)*(i_mm+1)), 2, array_shape);
     }
 
     dcl_freecrealary(i_s);
@@ -773,12 +773,12 @@ dcl_shtw2g(obj, mm, jm, im, w, work)
     i_w = dcl_obj2crealary(w);
     i_work = dcl_obj2crealary(work);
 
-    o_g= ALLOCA_N(real, (2*i_im+1)*(2*i_jm+1));
+    o_g= ALLOCA_N(real, ((2*i_im+1)*(2*i_jm+1)));
 
     shtw2g_(&i_mm, &i_jm, &i_im, i_w, o_g, i_work);
 
-    {int array_shape[1] = {(2*i_im+1)*(2*i_jm+1)};
-     g = dcl_crealary2obj(o_g, (2*i_im+1)*(2*i_jm+1), 1, array_shape);
+    {int array_shape[2] = {(2*i_im+1), (2*i_jm+1)};
+     g = dcl_crealary2obj(o_g, ((2*i_im+1)*(2*i_jm+1)), 2, array_shape);
     }
 
     dcl_freecrealary(i_w);
@@ -840,12 +840,12 @@ dcl_shtwga(obj, mm, jm, im, m1, m2, w, work)
     i_w = dcl_obj2crealary(w);
     i_work = dcl_obj2crealary(work);
 
-    o_g= ALLOCA_N(real, (2*i_im+1)*(2*i_jm+1));
+    o_g= ALLOCA_N(real, ((2*i_im+1)*(2*i_jm+1)));
 
     shtwga_(&i_mm, &i_jm, &i_im, &i_m1, &i_m2, i_w, o_g, i_work);
 
-    {int array_shape[1] = {(2*i_im+1)*(2*i_jm+1)};
-     g = dcl_crealary2obj(o_g, (2*i_im+1)*(2*i_jm+1), 1, array_shape);
+    {int array_shape[2] = {(2*i_im+1), (2*i_jm+1)};
+     g = dcl_crealary2obj(o_g, ((2*i_im+1)*(2*i_jm+1)), 2, array_shape);
     }
 
     dcl_freecrealary(i_w);
@@ -911,12 +911,12 @@ dcl_shtwgm(obj, mm, jm, im, m, wr, wi, work)
     i_wi = dcl_obj2crealary(wi);
     i_work = dcl_obj2crealary(work);
 
-    o_g= ALLOCA_N(real, (2*i_im+1)*(2*i_jm+1));
+    o_g= ALLOCA_N(real, ((2*i_im+1)*(2*i_jm+1)));
 
     shtwgm_(&i_mm, &i_jm, &i_im, &i_m, i_wr, i_wi, o_g, i_work);
 
-    {int array_shape[1] = {(2*i_im+1)*(2*i_jm+1)};
-     g = dcl_crealary2obj(o_g, (2*i_im+1)*(2*i_jm+1), 1, array_shape);
+    {int array_shape[2] = {(2*i_im+1), (2*i_jm+1)};
+     g = dcl_crealary2obj(o_g, ((2*i_im+1)*(2*i_jm+1)), 2, array_shape);
     }
 
     dcl_freecrealary(i_wr);
@@ -955,12 +955,12 @@ dcl_shtwgz(obj, jm, im, wz)
     i_im = NUM2INT(im);
     i_wz = dcl_obj2crealary(wz);
 
-    o_g= ALLOCA_N(real, (2*i_im+1)*(2*i_jm+1));
+    o_g= ALLOCA_N(real, ((2*i_im+1)*(2*i_jm+1)));
 
     shtwgz_(&i_jm, &i_im, i_wz, o_g);
 
-    {int array_shape[1] = {(2*i_im+1)*(2*i_jm+1)};
-     g = dcl_crealary2obj(o_g, (2*i_im+1)*(2*i_jm+1), 1, array_shape);
+    {int array_shape[2] = {(2*i_im+1), (2*i_jm+1)};
+     g = dcl_crealary2obj(o_g, ((2*i_im+1)*(2*i_jm+1)), 2, array_shape);
     }
 
     dcl_freecrealary(i_wz);
@@ -1073,12 +1073,12 @@ dcl_shtg2w(obj, mm, jm, im, g, work)
     i_g = dcl_obj2crealary(g);
     i_work = dcl_obj2crealary(work);
 
-    o_w= ALLOCA_N(real, (2*i_jm+1)*(2*i_mm+1));
+    o_w= ALLOCA_N(real, ((2*i_jm+1)*(2*i_mm+1)));
 
     shtg2w_(&i_mm, &i_jm, &i_im, i_g, o_w, i_work);
 
-    {int array_shape[1] = {(2*i_jm+1)*(2*i_mm+1)};
-     w = dcl_crealary2obj(o_w, (2*i_jm+1)*(2*i_mm+1), 1, array_shape);
+    {int array_shape[2] = {(2*i_jm+1), (2*i_mm+1)};
+     w = dcl_crealary2obj(o_w, ((2*i_jm+1)*(2*i_mm+1)), 2, array_shape);
     }
 
     dcl_freecrealary(i_g);
@@ -1137,16 +1137,16 @@ dcl_shts2g(obj, mm, jm, im, isw, s, work)
     i_s = dcl_obj2crealary(s);
     i_work = dcl_obj2crealary(work);
 
-    o_w= ALLOCA_N(real, (2*i_jm+1)*(2*i_mm+1));
-    o_g= ALLOCA_N(real, (2*i_im+1)*(2*i_jm+1));
+    o_w= ALLOCA_N(real, ((2*i_jm+1)*(2*i_mm+1)));
+    o_g= ALLOCA_N(real, ((2*i_im+1)*(2*i_jm+1)));
 
     shts2g_(&i_mm, &i_jm, &i_im, &i_isw, i_s, o_w, o_g, i_work);
 
-    {int array_shape[1] = {(2*i_jm+1)*(2*i_mm+1)};
-     w = dcl_crealary2obj(o_w, (2*i_jm+1)*(2*i_mm+1), 1, array_shape);
+    {int array_shape[2] = {(2*i_jm+1), (2*i_mm+1)};
+     w = dcl_crealary2obj(o_w, ((2*i_jm+1)*(2*i_mm+1)), 2, array_shape);
     }
-    {int array_shape[1] = {(2*i_im+1)*(2*i_jm+1)};
-     g = dcl_crealary2obj(o_g, (2*i_im+1)*(2*i_jm+1), 1, array_shape);
+    {int array_shape[2] = {(2*i_im+1), (2*i_jm+1)};
+     g = dcl_crealary2obj(o_g, ((2*i_im+1)*(2*i_jm+1)), 2, array_shape);
     }
 
     dcl_freecrealary(i_s);
@@ -1215,16 +1215,16 @@ dcl_shtsga(obj, mm, jm, im, isw, m1, m2, s, work)
     i_s = dcl_obj2crealary(s);
     i_work = dcl_obj2crealary(work);
 
-    o_w= ALLOCA_N(real, (2*i_jm+1)*(2*i_mm+1));
-    o_g= ALLOCA_N(real, (2*i_im+1)*(2*i_jm+1));
+    o_w= ALLOCA_N(real, ((2*i_jm+1)*(2*i_mm+1)));
+    o_g= ALLOCA_N(real, ((2*i_im+1)*(2*i_jm+1)));
 
     shtsga_(&i_mm, &i_jm, &i_im, &i_isw, &i_m1, &i_m2, i_s, o_w, o_g, i_work);
 
-    {int array_shape[1] = {(2*i_jm+1)*(2*i_mm+1)};
-     w = dcl_crealary2obj(o_w, (2*i_jm+1)*(2*i_mm+1), 1, array_shape);
+    {int array_shape[2] = {(2*i_jm+1), (2*i_mm+1)};
+     w = dcl_crealary2obj(o_w, ((2*i_jm+1)*(2*i_mm+1)), 2, array_shape);
     }
-    {int array_shape[1] = {(2*i_im+1)*(2*i_jm+1)};
-     g = dcl_crealary2obj(o_g, (2*i_im+1)*(2*i_jm+1), 1, array_shape);
+    {int array_shape[2] = {(2*i_im+1), (2*i_jm+1)};
+     g = dcl_crealary2obj(o_g, ((2*i_im+1)*(2*i_jm+1)), 2, array_shape);
     }
 
     dcl_freecrealary(i_s);
@@ -1284,15 +1284,15 @@ dcl_shtsgz(obj, mm, jm, im, isw, s, work)
     i_work = dcl_obj2crealary(work);
 
     o_wz= ALLOCA_N(real, (2*i_jm+1));
-    o_g= ALLOCA_N(real, (2*i_im+1)*(2*i_jm+1));
+    o_g= ALLOCA_N(real, ((2*i_im+1)*(2*i_jm+1)));
 
     shtsgz_(&i_mm, &i_jm, &i_im, &i_isw, i_s, o_wz, o_g, i_work);
 
     {int array_shape[1] = {2*i_jm+1};
      wz = dcl_crealary2obj(o_wz, (2*i_jm+1), 1, array_shape);
     }
-    {int array_shape[1] = {(2*i_im+1)*(2*i_jm+1)};
-     g = dcl_crealary2obj(o_g, (2*i_im+1)*(2*i_jm+1), 1, array_shape);
+    {int array_shape[2] = {(2*i_im+1), (2*i_jm+1)};
+     g = dcl_crealary2obj(o_g, ((2*i_im+1)*(2*i_jm+1)), 2, array_shape);
     }
 
     dcl_freecrealary(i_s);
@@ -1360,7 +1360,7 @@ dcl_shtsgm(obj, mm, jm, im, m, isw, s, work)
 
     o_wr= ALLOCA_N(real, (2*i_jm+1));
     o_wi= ALLOCA_N(real, (2*i_jm+1));
-    o_g= ALLOCA_N(real, (2*i_im+1)*(2*i_jm+1));
+    o_g= ALLOCA_N(real, ((2*i_im+1)*(2*i_jm+1)));
 
     shtsgm_(&i_mm, &i_jm, &i_im, &i_m, &i_isw, i_s, o_wr, o_wi, o_g, i_work);
 
@@ -1370,8 +1370,8 @@ dcl_shtsgm(obj, mm, jm, im, m, isw, s, work)
     {int array_shape[1] = {2*i_jm+1};
      wi = dcl_crealary2obj(o_wi, (2*i_jm+1), 1, array_shape);
     }
-    {int array_shape[1] = {(2*i_im+1)*(2*i_jm+1)};
-     g = dcl_crealary2obj(o_g, (2*i_im+1)*(2*i_jm+1), 1, array_shape);
+    {int array_shape[2] = {(2*i_im+1), (2*i_jm+1)};
+     g = dcl_crealary2obj(o_g, ((2*i_im+1)*(2*i_jm+1)), 2, array_shape);
     }
 
     dcl_freecrealary(i_s);
@@ -1513,13 +1513,13 @@ dcl_shtg2s(obj, mm, jm, im, isw, g, work)
     i_g = dcl_obj2crealary(g);
     i_work = dcl_obj2crealary(work);
 
-    o_w= ALLOCA_N(real, (2*i_jm+1)*(2*i_mm+1));
+    o_w= ALLOCA_N(real, ((2*i_jm+1)*(2*i_mm+1)));
     o_s= ALLOCA_N(real, (i_mm+1)*(i_mm+1));
 
     shtg2s_(&i_mm, &i_jm, &i_im, &i_isw, i_g, o_w, o_s, i_work);
 
-    {int array_shape[1] = {(2*i_jm+1)*(2*i_mm+1)};
-     w = dcl_crealary2obj(o_w, (2*i_jm+1)*(2*i_mm+1), 1, array_shape);
+    {int array_shape[2] = {(2*i_jm+1), (2*i_mm+1)};
+     w = dcl_crealary2obj(o_w, ((2*i_jm+1)*(2*i_mm+1)), 2, array_shape);
     }
     {int array_shape[1] = {(i_mm+1)*(i_mm+1)};
      s = dcl_crealary2obj(o_s, (i_mm+1)*(i_mm+1), 1, array_shape);
